@@ -1,5 +1,6 @@
 import logging
 import os
+import typing
 from typing import Any
 
 import yaml
@@ -11,15 +12,19 @@ class ConfigBase:
         # 获取field指
         raise NotImplementedError
 
-    def _get_field_type(self, field: str) -> type:
+    def _get_field_type(self, field: str):
         # 获取field的类型
         if field in self.__annotations__:
             return self.__annotations__[field]
 
     @classmethod
     def _parse_field_type(cls, _type, value):
-        func = getattr(cls, f"_parse_{_type.__name__}", cls._parse_str)
-        return func(value)
+        try:
+            func = getattr(cls, f"_parse_{_type.__name__}", cls._parse_str)
+            return func(value)
+        except AttributeError:
+            func = getattr(cls, f"_parse_{_type.__origin__}", cls._parse_list)
+            return func(_type, value)
 
     @staticmethod
     def _parse_bool(value: str) -> bool:
@@ -44,8 +49,17 @@ class ConfigBase:
             return 0
 
     @staticmethod
-    def _parse_list(value: str) -> list:
-        return value.split(",")
+    def _parse_list(_type, value: str) -> list:
+        value = value.split(",")
+        result = list()
+        for v in value:
+            for t in _type.__args__:
+                try:
+                    result.append(t(v))
+                    break
+                except ValueError:
+                    continue
+        return result
 
     def fetch(self):
         for field in self.__annotations__.keys():
