@@ -62,7 +62,7 @@ class Sso:
         else:
             return False
 
-    def _token_to_user_id(self, token: str) -> str:
+    def token_to_user_id(self, token: str) -> str:
         return self.decode_token(token)["user_id"]
 
     def _add_token(self, token: str, user_id: str):
@@ -81,7 +81,7 @@ class Sso:
         :param token: token
         :return:
         """
-        user_id = self._token_to_user_id(token)
+        user_id = self.token_to_user_id(token)
         self._redis.hdel(self._redis_key, user_id)
 
     def _exists_token(self, token: str) -> bool:
@@ -91,7 +91,7 @@ class Sso:
         :return:
         """
         try:
-            user_id = self._token_to_user_id(token)
+            user_id = self.token_to_user_id(token)
             # 该token 与对应user id 在redis中存在的token是否一致
             return token.encode() == self._redis.hget(self._redis_key, user_id)
         except JWTError:
@@ -102,22 +102,36 @@ class Sso:
         def wrapper(*args, **kwargs):
             token = kwargs.get("token")
             # token存在且未过期未过期
-            if self._exists_token(token) and self.check_expire(token):
-                return func(*args, **kwargs)
-            else:
+            try:
+                if self._exists_token(token) and self.check_expire(token):
+                    return func(*args, **kwargs)
+                else:
+                    return JSONResponse(
+                        {"msg": "token不存在或已过期"},
+                        status_code=status.HTTP_401_UNAUTHORIZED,
+                    )
+            except Exception as e:
                 return JSONResponse(
-                    {"msg": "token不存在或已过期"}, status_code=status.HTTP_401_UNAUTHORIZED
+                    {"msg": "无效的token:{}, error_msg:{}".format(token, e)},
+                    status_code=status.HTTP_401_UNAUTHORIZED,
                 )
 
         @wraps(func)
         async def async_wrapper(*args, **kwargs):
             token = kwargs.get("token")
             # token存在且未过期未过期
-            if self._exists_token(token) and self.check_expire(token):
-                return await func(*args, **kwargs)
-            else:
+            try:
+                if self._exists_token(token) and self.check_expire(token):
+                    return await func(*args, **kwargs)
+                else:
+                    return JSONResponse(
+                        {"msg": "token不存在或已过期"},
+                        status_code=status.HTTP_401_UNAUTHORIZED,
+                    )
+            except Exception as e:
                 return JSONResponse(
-                    {"msg": "token不存在或已过期"}, status_code=status.HTTP_401_UNAUTHORIZED
+                    {"msg": "无效的token:{}, error_msg:{}".format(token, e)},
+                    status_code=status.HTTP_401_UNAUTHORIZED,
                 )
 
         if inspect.iscoroutinefunction(func):
@@ -126,6 +140,18 @@ class Sso:
             return wrapper
 
     def login(self, user_id: str) -> str:
+        """
+        通过user_id登录
+
+        :param user_id: 企业微信user_id
+        :return: 有效的token
+        """
+        # 判断该user_id 对应的token是否在redis中，如果存在，判断token是否过期，如果没有过期直接返回
+        # 如果过期重新生成token存储redis中并返回
+        token = self._redis.hget(self._redis_key, user_id)
+        token = token.decode() if token else None
+        if token and self.check_expire(token):
+            return token
         token = self.generate_token(user_id)
         self._add_token(token, user_id)
         return token
